@@ -8,7 +8,7 @@
  *
  * ------------- An Efficient RSerPool Prototype Implementation -------------
  *
- * Copyright (C) 2002-2022 by Thomas Dreibholz
+ * Copyright (C) 2002-2023 by Thomas Dreibholz
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * Contact: dreibh@iem.uni-due.de
+ * Contact: thomas.dreibholz@gmail.com
  */
 
 #include <string>
@@ -183,6 +183,14 @@ start:
             }
             loadInfo.rli_policy = PPT_PRIORITY_LEASTUSED;
          }
+         else if(sscanf((const char*)&argv[i][8], "PriorityLeastUsedDegradation:%lf", &degradation) == 1) {
+            loadInfo.rli_load_degradation = (unsigned int)rint(degradation * (double)PPV_MAX_LOAD_DEGRADATION);
+            if(loadInfo.rli_load_degradation > PPV_MAX_LOAD_DEGRADATION) {
+               fputs("ERROR: Bad PLU degradation value!\n", stderr);
+               exit(1);
+            }
+            loadInfo.rli_policy = PPT_PRIORITY_LEASTUSED_DEGRADATION;
+         }
          else if(!(strcmp((const char*)&argv[i][8], "RandomizedPriorityLeastUsed"))) {
             loadInfo.rli_policy = PPT_RANDOMIZED_PRIORITY_LEASTUSED;
          }
@@ -207,6 +215,19 @@ start:
             }
             loadInfo.rli_policy = PPT_LEASTUSED_DEGRADATION_DPF;
          }
+         else if(sscanf((const char*)&argv[i][8], "PriorityLeastUsedDegradationDPF:%lf:%lf", &degradation, &dpf) == 2) {
+            if((dpf < 0.0) || (dpf > 1.0)) {
+               fputs("ERROR: Bad LU-DPF DPF value!\n", stderr);
+               exit(1);
+            }
+            loadInfo.rli_load_dpf         = (unsigned int)rint(dpf * (double)PPV_MAX_LOADDPF);
+            loadInfo.rli_load_degradation = (unsigned int)rint(degradation * (double)PPV_MAX_LOAD_DEGRADATION);
+            if(loadInfo.rli_load_degradation > PPV_MAX_LOAD_DEGRADATION) {
+               fputs("ERROR: Bad LU-DPF degradation value!\n", stderr);
+               exit(1);
+            }
+            loadInfo.rli_policy = PPT_PRIORITY_LEASTUSED_DEGRADATION_DPF;
+         }
          else if(sscanf((const char*)&argv[i][8], "WeightedRoundRobin:%u", &loadInfo.rli_weight) == 1) {
             loadInfo.rli_policy = PPT_WEIGHTED_ROUNDROBIN;
          }
